@@ -1,7 +1,7 @@
 import os
 
 import visidata
-from visidata import Extensible, VisiData, vd, EscapeException
+from visidata import Extensible, VisiData, vd, EscapeException, cleanName
 from unittest import mock
 
 
@@ -19,6 +19,9 @@ class LazyChainMap:
                 if k not in self.objs:
                     self.objs[k] = obj
 
+    def __contains__(self, k):
+        return k in self.objs
+
     def keys(self):
         return list(self.objs.keys())  # sum(set(dir(obj)) for obj in self.objs))
 
@@ -87,8 +90,9 @@ class BaseSheet(DrawablePane):
         return vd.OptionsObject(vd._options, obj=self)
 
     def __init__(self, *names, **kwargs):
-        self._name = None
-        self.name = self.options.name_joiner.join(str(x) for x in names)
+        self._name = None   # initial cache value necessary for self.options
+        self.names = names
+        self.name = self.options.name_joiner.join(str(x) for x in self.names)
         self.source = None
         self.rows = UNLOADED      # list of opaque objects
         self._scr = mock.MagicMock(__bool__=mock.Mock(return_value=False))  # disable curses in batch mode
@@ -145,7 +149,7 @@ class BaseSheet(DrawablePane):
         cmd = self.getCommand(cmd or keystrokes)
         if not cmd:
             if keystrokes:
-                vd.debug('no command "%s"' % keystrokes)
+                vd.status('no command for %s' % keystrokes)
             return False
 
         escaped = False
@@ -154,6 +158,8 @@ class BaseSheet(DrawablePane):
         if vdglobals is None:
             vdglobals = vd.getGlobals()
 
+        vd.cmdlog  # make sure cmdlog has been created for first command
+
         try:
             for hookfunc in vd.beforeExecHooks:
                 hookfunc(self, cmd, '', keystrokes)
@@ -176,20 +182,31 @@ class BaseSheet(DrawablePane):
         vd.clearCaches()
         return escaped
 
+    @property
+    def names(self):
+        return self._names
+
+    @names.setter
+    def names(self, names):
+        self._names = names
+        self.name = self.options.name_joiner.join(self.maybeClean(str(x)) for x in self._names)
+
     @property
     def name(self):
         'Name of this sheet.'
-        try:
-            return self._name
-        except AttributeError:
-            return self.rowtype
+        return self._name
 
     @name.setter
     def name(self, name):
         'Set name without spaces.'
-        if self._name:
-            vd.addUndo(setattr, self, '_name', self._name)
-        self._name = visidata.maybe_clean(str(name), self)
+        if self._names:
+            vd.addUndo(setattr, self, '_names', self._names)
+        self._name = self.maybeClean(str(name))
+
+    def maybeClean(self, s):
+        if self.options.clean_names:
+            s = cleanName(s)
+        return s
 
     def recalc(self):
         'Clear any calculated value caches.'
@@ -270,7 +287,7 @@ def getSheet(vd, sheetname):
         pass
 
     if sheetname == 'options':
-        vs = self.optionsSheet
+        vs = vd.globalOptionsSheet
         vs.reload()
         vs.vd = vd
         return vs
