@@ -3,40 +3,43 @@ import threading
 from visidata import *
 import visidata
 
-option('replay_wait', 0.0, 'time to wait between replayed commands, in seconds', sheettype=None)
-theme('disp_replay_play', '▶', 'status indicator for active replay')
-theme('disp_replay_pause', '‖', 'status indicator for paused replay')
-theme('color_status_replay', 'green', 'color of replay status indicator')
-option('replay_movement', False, 'insert movements during replay', sheettype=None)
-option('visidata_dir', '~/.visidata/', 'directory to load and store additional files', sheettype=None)
+vd.option('replay_wait', 0.0, 'time to wait between replayed commands, in seconds', sheettype=None)
+vd.option('disp_replay_play', '▶', 'status indicator for active replay')
+vd.option('disp_replay_pause', '‖', 'status indicator for paused replay')
+vd.option('color_status_replay', 'green', 'color of replay status indicator')
+vd.option('replay_movement', False, 'insert movements during replay', sheettype=None)
 
 # prefixes which should not be logged
 nonLogged = '''forget exec-longname undo redo quit
 show error errors statuses options threads jump
-replay cancel save-cmdlog macro
+replay cancel save-cmdlog macro cmdlog-sheet
 go- search scroll prev next page start end zoom resize visibility
 mouse suspend redraw no-op help syscopy sysopen profile toggle'''.split()
 
-option('rowkey_prefix', 'キ', 'string prefix for rowkey in the cmdlog', sheettype=None)
-option('cmdlog_histfile', '', 'file to autorecord each cmdlog action to', sheettype=None)
+vd.option('rowkey_prefix', 'キ', 'string prefix for rowkey in the cmdlog', sheettype=None)
+vd.option('cmdlog_histfile', '', 'file to autorecord each cmdlog action to', sheettype=None)
 
 vd.activeCommand = UNLOADED
 
-def open_vd(p):
+@VisiData.api
+def open_vd(vd, p):
     return CommandLog(p.name, source=p, precious=True)
 
-def open_vdj(p):
+@VisiData.api
+def open_vdj(vd, p):
     return CommandLogJsonl(p.name, source=p, precious=True)
 
 VisiData.save_vd = VisiData.save_tsv
 VisiData.save_vdj = VisiData.save_jsonl
 
 
-def checkVersion(desired_version):
+@VisiData.api
+def checkVersion(vd, desired_version):
     if desired_version != visidata.__version_info__:
         vd.fail("version %s required" % desired_version)
 
-def fnSuffix(prefix):
+@VisiData.api
+def fnSuffix(vd, prefix):
     i = 0
     fn = prefix + '.vd'
     while Path(fn).exists():
@@ -45,6 +48,7 @@ def fnSuffix(prefix):
 
     return fn
 
+@BaseSheet.api
 def inputLongname(sheet):
     longnames = set(k for (k, obj), v in vd.commands.iter(sheet))
     return vd.input("command name: ", completer=CompleteKey(sorted(longnames)), type='longname')
@@ -58,7 +62,8 @@ def indexMatch(L, func):
 def keystr(k):
     return  options.rowkey_prefix+','.join(map(str, k))
 
-def isLoggableCommand(longname):
+@VisiData.api
+def isLoggableCommand(vd, longname):
     for n in nonLogged:
         if longname.startswith(n):
             return False
@@ -155,9 +160,6 @@ class _CommandLog:
         return self._rowtype(**fields)
 
     def beforeExecHook(self, sheet, cmd, args, keystrokes):
-        if not isLoggableCommand(cmd.longname):
-            return
-
         if vd.activeCommand:
             self.afterExecSheet(sheet, False, '')
 
@@ -190,15 +192,23 @@ class _CommandLog:
         if err:
             vd.activeCommand[-1] += ' [%s]' % err
 
-        # remove user-aborted commands and simple movements
-        if not escaped and isLoggableCommand(vd.activeCommand.longname):
-            if isLoggableSheet(sheet):      # don't record actions on global cmdlog or other internal sheets
-                    self.addRow(vd.activeCommand)  # add to global cmdlog
+        if escaped:
+            vd.activeCommand = None
+            return
+
+        # remove user-aborted commands and simple movements (unless first command on the sheet, which created the sheet)
+        if not sheet.cmdlog.rows or vd.isLoggableCommand(vd.activeCommand.longname):
+            if isLoggableSheet(sheet):      # don't record actions from cmdlog or other internal sheets on global cmdlog
+                self.addRow(vd.activeCommand)  # add to global cmdlog
             sheet.cmdlog_sheet.addRow(vd.activeCommand)  # add to sheet-specific cmdlog
             if options.cmdlog_histfile:
+                name = date().strftime(options.cmdlog_histfile)
+                p = Path(name)
+                if not p.is_absolute():
+                    p = Path(options.visidata_dir)/f'{name}.jsonl'
                 if not getattr(vd, 'sessionlog', None):
-                    vd.sessionlog = vd.loadInternalSheet(CommandLog, Path(date().strftime(options.cmdlog_histfile)))
-                append_tsv_row(vd.sessionlog, vd.activeCommand)
+                    vd.sessionlog = vd.loadInternalSheet(CommandLog, p)
+                vd.sessionlog.append_tsv_row(vd.activeCommand)
 
         vd.activeCommand = None
 
@@ -361,6 +371,9 @@ def replay_sync(vd, cmdlog, live=False):
 @asyncthread
 def replay(vd, cmdlog):
         'Inject commands into live execution with interface.'
+        for thread in vd.threads:
+            if thread.name == 'replay':
+                thread.noblock = True
         vd.replay_sync(cmdlog, live=True)
 
 
@@ -426,7 +439,7 @@ def cmdlog(vd):
 
 @VisiData.property
 def modifyCommand(vd):
-    if vd.activeCommand is not None and isLoggableCommand(vd.activeCommand.longname):
+    if vd.activeCommand is not None and vd.isLoggableCommand(vd.activeCommand.longname):
         return vd.activeCommand
     if not vd.cmdlog.rows:
         return None
@@ -445,10 +458,10 @@ globalCommand('^N', 'replay-advance', 'vd.replay_advance()', 'execute next row i
 globalCommand('^K', 'replay-stop', 'vd.replay_cancel()', 'cancel current replay')
 
 globalCommand(None, 'show-status', 'status(input("status: "))', 'show given message on status line')
-globalCommand('^V', 'show-version', 'status(__version_info__);', 'show version and copyright information on status line')
+globalCommand('^V', 'show-version', 'status(__version_info__);', 'Show version and copyright information on status line')
 globalCommand('z^V', 'check-version', 'checkVersion(input("require version: ", value=__version_info__))', 'check VisiData version against given version')
 
-globalCommand(' ', 'exec-longname', 'execCommand(inputLongname(sheet))', 'execute command by its longname')
+globalCommand(' ', 'exec-longname', 'execCommand(inputLongname())', 'execute command by its longname')
 
 CommandLog.addCommand('x', 'replay-row', 'vd.replayOne(cursorRow); status("replayed one row")', 'replay command in current row')
 CommandLog.addCommand('gx', 'replay-all', 'vd.replay(sheet)', 'replay contents of entire CommandLog')
