@@ -1,4 +1,5 @@
 import os
+import sys
 import signal
 import subprocess
 import tempfile
@@ -21,16 +22,24 @@ class SuspendCurses:
         curses.doupdate()
 
 
-@visidata.VisiData.global_api
+@visidata.VisiData.api
 def launchEditor(vd, *args):
     'Launch $EDITOR with *args* as arguments.'
     editor = os.environ.get('EDITOR') or vd.fail('$EDITOR not set')
-    args = [editor] + list(args)
+    args = editor.split() + list(args)
     with SuspendCurses():
         return subprocess.call(args)
 
 
-@visidata.VisiData.global_api
+@visidata.VisiData.api
+def launchBrowser(vd, *args):
+    'Launch $BROWSER with *args* as arguments.'
+    browser = os.environ.get('BROWSER') or vd.fail('(no $BROWSER) for %s' % args[0])
+    args = [browser] + list(args)
+    subprocess.call(args)
+
+
+@visidata.VisiData.api
 def launchExternalEditor(vd, v, linenum=0):
     'Launch $EDITOR to edit string *v* starting on line *linenum*.'
     import tempfile
@@ -43,9 +52,9 @@ def launchExternalEditor(vd, v, linenum=0):
 def launchExternalEditorPath(path, linenum=0):
         'Launch $EDITOR to edit *path* starting on line *linenum*.'
         if linenum:
-            launchEditor(path, '+%s' % linenum)
+            visidata.vd.launchEditor(path, '+%s' % linenum)
         else:
-            launchEditor(path)
+            visidata.vd.launchEditor(path)
 
         with open(path, 'r') as fp:
             try:
@@ -61,4 +70,26 @@ def suspend():
         os.kill(os.getpid(), signal.SIGSTOP)
 
 
-visidata.globalCommand('^Z', 'suspend', 'suspend()', 'suspend VisiData process')
+def _breakpoint(*args, **kwargs):
+    import pdb
+    class VisiDataPdb(pdb.Pdb):
+        def precmd(self, line):
+            r = super().precmd(line)
+            if not r:
+                SuspendCurses.__exit__(None, None, None, None)
+            return r
+
+        def postcmd(self, stop, line):
+            if stop:
+                SuspendCurses.__enter__(None)
+            return super().postcmd(stop, line)
+
+    SuspendCurses.__enter__(None)
+    VisiDataPdb(nosigint=True).set_trace()
+
+
+sys.breakpointhook = _breakpoint
+
+
+visidata.BaseSheet.addCommand('^Z', 'suspend', 'suspend()', 'suspend VisiData process')
+visidata.BaseSheet.addCommand('', 'breakpoint', 'breakpoint()', 'drop into pdb REPL')
