@@ -1,12 +1,14 @@
 import re
 
-from visidata import *
+from visidata import VisiData, vd, Sheet, options, Column, Progress, anytype, date, ColumnItem, asyncthread, TypedExceptionWrapper, TypedWrapper, IndexSheet, copy, currency, clean_to_id
 
-def open_sqlite(p):
+
+@VisiData.api
+def open_sqlite(vd, p):
     return SqliteIndexSheet(p.name, source=p)
 
-open_sqlite3 = open_sqlite
-open_db = open_sqlite
+VisiData.open_sqlite3 = VisiData.open_sqlite
+VisiData.open_db = VisiData.open_sqlite
 
 # rowdef: list of values
 class SqliteSheet(Sheet):
@@ -20,7 +22,9 @@ class SqliteSheet(Sheet):
 
     def conn(self):
         import sqlite3
-        return sqlite3.connect(str(self.resolve()))
+        con = sqlite3.connect(str(self.resolve()))
+        con.text_factory = lambda s, enc=self.options.encoding, encerrs=self.options.encoding_errors: s.decode(enc, encerrs)
+        return con
 
     def execute(self, conn, sql, parms=None):
         parms = parms or []
@@ -28,6 +32,8 @@ class SqliteSheet(Sheet):
         return conn.execute(sql, parms)
 
     def iterload(self):
+        import sqlite3
+
         def parse_sqlite_type(t):
             m = re.match(r'(\w+)(\((\d+)(,(\d+))?\))?', t.upper())
             if not m: return anytype
@@ -39,11 +45,11 @@ class SqliteSheet(Sheet):
                 return int if f == '0' else float
             return anytype
 
+        self.rowidColumn = None
         with self.conn() as conn:
             tblname = self.tableName
             if not isinstance(self, SqliteIndexSheet):
                 self.columns = []
-                self.addColumn(ColumnItem('rowid', 0, type=int, width=0))
                 for r in self.execute(conn, 'PRAGMA TABLE_XINFO("%s")' % tblname):
                     colnum, colname, coltype, nullable, defvalue, colkey, *_ = r
                     c = ColumnItem(colname, colnum+1, type=parse_sqlite_type(coltype))
@@ -52,7 +58,15 @@ class SqliteSheet(Sheet):
                     if colkey:
                         self.setKeys([c])
 
-            r = self.execute(conn, 'SELECT rowid, * FROM "%s"' % tblname)
+                sql = self.row[5]  # SQL used to create table
+                if 'WITHOUT ROWID' not in sql and 'CREATE VIEW' not in sql:
+                    self.rowidColumn = ColumnItem('rowid', 0, type=int, width=0)
+                    self.addColumn(self.rowidColumn, index=0)
+
+            if self.rowidColumn:
+                r = self.execute(conn, 'SELECT rowid, * FROM "%s"' % tblname)
+            else:
+                r = self.execute(conn, 'SELECT NULL, * FROM "%s"' % tblname)
             yield from Progress(r, total=r.rowcount-1)
 
     @asyncthread
@@ -77,7 +91,6 @@ class SqliteSheet(Sheet):
             return vals
 
         with self.conn() as conn:
-            wherecols = [self.columns[0]] # self.column("rowid")
             for r in adds.values():
                 cols = self.visibleCols
                 sql = 'INSERT INTO "%s" ' % self.tableName
@@ -88,6 +101,10 @@ class SqliteSheet(Sheet):
                     vd.warning('not all rows inserted') # f'{res.rowcount}/{res.arraysize} rows inserted'
 
             for row, rowmods in mods.values():
+                if not self.rowidColumn:
+                    vd.warning('cannot modify rows in tables without rowid')
+                    break
+                wherecols = [self.rowidColumn]
                 sql = 'UPDATE "%s" SET ' % self.tableName
                 sql += ', '.join('%s=?' % c.name for c, _ in rowmods.items())
                 sql += ' WHERE %s' % ' AND '.join('"%s"=?' % c.name for c in wherecols)
@@ -99,6 +116,11 @@ class SqliteSheet(Sheet):
                     vd.warning('not all rows updated') # f'{res.rowcount}/{res.arraysize} rows updated'
 
             for row in dels.values():
+                if not self.rowidColumn:
+                    vd.warning('cannot delete rows in tables without rowid')
+                    break
+
+                wherecols = [self.rowidColumn]
                 sql = 'DELETE FROM "%s" ' % self.tableName
                 sql += ' WHERE %s' % ' AND '.join('"%s"=?' % c.name for c in wherecols)
                 wherevals=list(Column.calcValue(c, row) for c in wherecols)
@@ -118,6 +140,7 @@ class SqliteIndexSheet(SqliteSheet, IndexSheet):
     savesToSource = True
     defer = True
     def iterload(self):
+        self.addColumn(Column('sql', width=0, getter=lambda c,r:r.row[5]))
         for row in SqliteSheet.iterload(self):
             if row[1] != 'index':
                 tblname = row[2]
@@ -165,6 +188,7 @@ class SqliteQuerySheet(SqliteSheet):
 def save_sqlite(vd, p, *vsheets):
     import sqlite3
     conn = sqlite3.connect(str(p))
+    conn.text_factory = lambda s, enc=vsheets[0].options.encoding: s.decode(enc)
     conn.row_factory = sqlite3.Row
     c = conn.cursor()
 
@@ -198,7 +222,7 @@ def save_sqlite(vd, p, *vsheets):
                 elif not isinstance(v, (int, float, str)):
                     v = col.getDisplayValue(r)
                 sqlvals.append(v)
-            sql = 'INSERT INTO "%s" VALUES (%s)' % (tblname, ','.join('?' for v in sqlvals))
+            sql = 'INSERT INTO "%s" (%s) VALUES (%s)' % (tblname, ','.join(f'"{c.name}"' for c in vs.visibleCols), ','.join('?' for v in sqlvals))
             c.execute(sql, sqlvals)
 
     conn.commit()
