@@ -1,12 +1,12 @@
 import collections
 
-from visidata import globalCommand, BaseSheet, Column, options, vd, anytype, ENTER, asyncthread, option, Sheet, IndexSheet
+from visidata import globalCommand, BaseSheet, Column, options, vd, anytype, ENTER, asyncthread, Sheet, IndexSheet
 from visidata import CellColorizer, RowColorizer, JsonLinesSheet, AttrDict
 from visidata import ColumnAttr, ColumnItem
 from visidata import TsvSheet, Path, Option
 from visidata import undoAttrFunc, VisiData, vlen
 
-option('visibility', 0, 'visibility level (0=low, 1=high)')
+vd.option('visibility', 0, 'visibility level (0=low, 1=high)')
 
 vd_system_sep = '\t'
 
@@ -85,7 +85,7 @@ class OptionsSheet(Sheet):
     rowtype = 'options'
     precious = False
     columns = (
-        ColumnAttr('option', 'name'),
+        Column('option', getter=lambda col,row: row.name),
         Column('value',
             getter=lambda col,row: col.sheet.diffOption(row.name),
             setter=lambda col,row,val: options.set(row.name, val, col.sheet.source),
@@ -155,13 +155,17 @@ class LastInputsSheet(JsonLinesSheet):
         return list(vd._lastInputs[t].keys())
 
 
-@VisiData.cached_property
+@VisiData.lazy_property
 def lastInputsSheet(vd):
     name = options.input_history
+
     if not name:
         return LastInputsSheet('last_inputs', source=None, rows=[])
 
-    p = Path(options.visidata_dir)/f'{options.input_history}.jsonl'
+    p = Path(name)
+    if not p.is_absolute():
+        p = Path(options.visidata_dir)/f'{name}.jsonl'
+
     vs = LastInputsSheet(name, source=p)
     try:
         vs.reload.__wrapped__(vs)
@@ -241,7 +245,7 @@ def join_cols(sheet):
 
 
 # copy vd.sheets so that ColumnsSheet itself isn't included (for recalc in addRow)
-globalCommand('gC', 'columns-all', 'vd.push(vd.allColumnsSheet)', 'open Columns Sheet: edit column properties for all visible columns from all sheets')
+globalCommand('gC', 'columns-all', 'vd.push(vd.allColumnsSheet)', 'open Columns Sheet: edit column properties for all visible columns from all sheets on the sheets stack')
 globalCommand('O', 'options-global', 'vd.push(vd.globalOptionsSheet)', 'open Options Sheet: edit global options (apply to all sheets)')
 
 BaseSheet.addCommand('V', 'open-vd', 'vd.push(vd.vdmenu)', 'open VisiData menu: browse list of core sheets')
@@ -272,3 +276,11 @@ OptionsSheet.addCommand(None, 'edit-option', 'editOption(cursorRow)', 'edit opti
 OptionsSheet.bindkey('e', 'edit-option')
 OptionsSheet.bindkey(ENTER, 'edit-option')
 MetaSheet.class_options.header = 0
+
+
+vd.addGlobals({
+    'ColumnsSheet': ColumnsSheet,
+    'MetaSheet': MetaSheet,
+    'OptionsSheet': OptionsSheet,
+    'VisiDataMetaSheet': VisiDataMetaSheet,
+})
