@@ -1,9 +1,8 @@
 import itertools
 import re
 
-from visidata import vd, VisiData, BaseSheet, Sheet, Column, Progress, globalCommand, ALT
+from visidata import vd, VisiData, BaseSheet, Sheet, Column, Progress, ALT, asyncthread
 
-__all__ = ['rotateRange']
 
 def rotateRange(n, idx, reverse=False):
     'Wraps an iter starting from idx. Yields indices from idx to n and then 0 to idx.'
@@ -61,19 +60,24 @@ def pageLeft(self):
 
 
 @Sheet.api
-def moveToNextRow(vs, func, reverse=False):
+@asyncthread
+def moveToNextRow(vs, func, reverse=False, msg='no different value up this column'):
     'Move cursor to next (prev if reverse) row for which func returns True.  Returns False if no row meets the criteria.'
     rng = range(vs.cursorRowIndex-1, -1, -1) if reverse else range(vs.cursorRowIndex+1, vs.nRows)
+    found = False
+    with Progress(total=len(vs.rows)) as prog:
+        for i in rng:
+            prog.addProgress(1)
+            try:
+                if func(vs.rows[i]):
+                    vs.cursorRowIndex = i
+                    found = True
+                    break
+            except Exception:
+                pass
 
-    for i in rng:
-        try:
-            if func(vs.rows[i]):
-                vs.cursorRowIndex = i
-                return True
-        except Exception:
-            pass
-
-    return False
+    if not found:
+        vd.status(msg)
 
 
 @Sheet.api
@@ -127,33 +131,30 @@ Sheet.addCommand('zc', 'go-col-number', 'sheet.cursorVisibleColIndex = int(input
 Sheet.addCommand('zr', 'go-row-number', 'sheet.cursorRowIndex = int(input("move to row number: "))', 'go to the given row number (0-based)')
 
 
-Sheet.addCommand('<', 'go-prev-value', 'moveToNextRow(lambda row,sheet=sheet,col=cursorCol,val=cursorTypedValue: col.getTypedValue(row) != val, reverse=True) or status("no different value up this column")', 'go up current column to next value'),
-Sheet.addCommand('>', 'go-next-value', 'moveToNextRow(lambda row,sheet=sheet,col=cursorCol,val=cursorTypedValue: col.getTypedValue(row) != val) or status("no different value down this column")', 'go down current column to next value'),
-Sheet.addCommand('{', 'go-prev-selected', 'moveToNextRow(lambda row,sheet=sheet: sheet.isSelected(row), reverse=True) or status("no previous selected row")', 'go up current column to previous selected row'),
-Sheet.addCommand('}', 'go-next-selected', 'moveToNextRow(lambda row,sheet=sheet: sheet.isSelected(row)) or status("no next selected row")', 'go down current column to next selected row'),
+Sheet.addCommand('<', 'go-prev-value', 'moveToNextRow(lambda row,sheet=sheet,col=cursorCol,val=cursorTypedValue: col.getTypedValue(row) != val, reverse=True, msg="no different value up this column")', 'go up current column to next value'),
+Sheet.addCommand('>', 'go-next-value', 'moveToNextRow(lambda row,sheet=sheet,col=cursorCol,val=cursorTypedValue: col.getTypedValue(row) != val, msg="no different value down this column")', 'go down current column to next value'),
+Sheet.addCommand('{', 'go-prev-selected', 'moveToNextRow(lambda row,sheet=sheet: sheet.isSelected(row), reverse=True, msg="no previous selected row")', 'go up current column to previous selected row'),
+Sheet.addCommand('}', 'go-next-selected', 'moveToNextRow(lambda row,sheet=sheet: sheet.isSelected(row), msg="no next selected row") ', 'go down current column to next selected row'),
 
-Sheet.addCommand('z<', 'go-prev-null', 'moveToNextRow(lambda row,col=cursorCol,isnull=isNullFunc(): isnull(col.getValue(row)), reverse=True) or status("no null down this column")', 'go up current column to next null value'),
-Sheet.addCommand('z>', 'go-next-null', 'moveToNextRow(lambda row,col=cursorCol,isnull=isNullFunc(): isnull(col.getValue(row))) or status("no null down this column")', 'go down current column to next null value'),
+Sheet.addCommand('z<', 'go-prev-null', 'moveToNextRow(lambda row,col=cursorCol,isnull=isNullFunc(): isnull(col.getValue(row)), reverse=True, msg="no null up this column")', 'go up current column to next null value'),
+Sheet.addCommand('z>', 'go-next-null', 'moveToNextRow(lambda row,col=cursorCol,isnull=isNullFunc(): isnull(col.getValue(row)), msg="no null down this column")', 'go down current column to next null value'),
 
 for i in range(1, 11):
-    globalCommand(ALT+str(i)[-1], 'jump-sheet-'+str(i), f'vd.push(*(list(s for s in allSheets if s.shortcut==str({i})) or fail("no sheet")))', f'jump to sheet {i}')
+    BaseSheet.addCommand(ALT+str(i)[-1], 'jump-sheet-'+str(i), f'vd.push(*(list(s for s in allSheets if s.shortcut==str({i})) or fail("no sheet")))', f'jump to sheet {i}')
 
 BaseSheet.bindkey('KEY_LEFT', 'go-left')
 BaseSheet.bindkey('KEY_DOWN', 'go-down')
 BaseSheet.bindkey('KEY_UP', 'go-up')
 BaseSheet.bindkey('KEY_RIGHT', 'go-right')
-BaseSheet.bindkey('KEY_HOME', 'go-leftmost')
-BaseSheet.bindkey('KEY_END', 'go-rightmost')
 BaseSheet.bindkey('KEY_NPAGE', 'go-pagedown')
 BaseSheet.bindkey('KEY_PPAGE', 'go-pageup')
 
-BaseSheet.bindkey('kHOM5', 'go-top')  # Ctrl+Home
-BaseSheet.bindkey('KEY_EOL', 'go-bottom')  # Ctrl+End
-
 BaseSheet.bindkey('gKEY_LEFT', 'go-leftmost'),
 BaseSheet.bindkey('gKEY_RIGHT', 'go-rightmost'),
 BaseSheet.bindkey('gKEY_UP', 'go-top'),
 BaseSheet.bindkey('gKEY_DOWN', 'go-bottom'),
+BaseSheet.bindkey('Home', 'go-top')
+BaseSheet.bindkey('End', 'go-bottom')
 
 Sheet.bindkey('BUTTON1_CLICKED', 'go-mouse')
 Sheet.bindkey('BUTTON3_PRESSED', 'go-mouse')
@@ -208,5 +209,10 @@ BaseSheet.bindkey('gl', 'go-rightmost')
 BaseSheet.addCommand('^^', 'jump-prev', 'vd.activeStack[1:] or fail("no previous sheet"); vd.push(vd.activeStack[1])', 'jump to previous sheet in this pane')
 BaseSheet.addCommand('g^^', 'jump-first', 'vd.push(vd.activeStack[-1])', 'jump to first sheet')
 
+BaseSheet.addCommand('BUTTON1_RELEASED', 'no-op', 'pass')
+
 BaseSheet.addCommand(None, 'mouse-enable', 'mm, _ = curses.mousemask(-1); status("mouse "+("ON" if mm else "OFF"))', 'enable mouse events')
 BaseSheet.addCommand(None, 'mouse-disable', 'mm, _ = curses.mousemask(0); status("mouse "+("ON" if mm else "OFF"))', 'disable mouse events')
+
+
+vd.addGlobals({'rotateRange': rotateRange})
