@@ -173,7 +173,7 @@ class PivotSheet(Sheet):
         numericBins = []
         degenerateBinning = False
         if numericCols:
-            nbins = options.histogram_bins or int(len(self.source.rows) ** (1./2))
+            nbins = self.source.options.histogram_bins or int(len(self.source.rows) ** (1./2))
             vals = tuple(numericCols[0].getValues(self.source.rows))
             minval = min(vals)
             maxval = max(vals)
@@ -252,3 +252,8 @@ class PivotSheet(Sheet):
 
 
 Sheet.addCommand('W', 'pivot', 'vd.push(Pivot(sheet, keyCols, [cursorCol]))', 'open Pivot Table: group rows by key column and summarize current column')
+
+vd.addGlobals({
+    'Pivot': Pivot,
+    'PivotGroupRow': PivotGroupRow,
+})
