@@ -1,12 +1,17 @@
+import os.path
 import os
+import sys
 import re
 import zipfile
+import shutil
 import importlib
+import subprocess
+import urllib
 
-from visidata import *
+from visidata import VisiData, vd, Path, CellColorizer, JsonLinesSheet, AttrDict, Column, Progress, ExpectedException, BaseSheet, asyncsingle, asyncthread
 
 
-option('plugins_url', 'https://visidata.org/plugins/plugins.jsonl', 'source of plugins sheet')
+vd.option('plugins_url', 'https://visidata.org/plugins/plugins.jsonl', 'source of plugins sheet')
 
 
 @VisiData.lazy_property
@@ -14,10 +19,10 @@ def pluginsSheet(p):
     return PluginsSheet('plugins_global')
 
 def _plugin_path(plugin):
-    return Path(os.path.join(options.visidata_dir, "plugins", plugin.name+".py"))
+    return Path(os.path.join(vd.options.visidata_dir, "plugins", plugin.name+".py"))
 
 def _plugin_init():
-    return Path(os.path.join(options.visidata_dir, "plugins", "__init__.py"))
+    return Path(os.path.join(vd.options.visidata_dir, "plugins", "__init__.py"))
 
 def _plugin_import(plugin):
     return "import " + _plugin_import_name(plugin)
@@ -55,6 +60,23 @@ def _pluginColorizer(s,c,r,v):
     if ver != r.latest_ver: return 'color_warning'
     return 'color_working'
 
+
+@VisiData.api
+def pipinstall(vd, deps):
+    'Install *deps*, a list of pypi modules to install via pip into the plugins-deps directory. Return True if successful (no error).'
+    p = subprocess.Popen([sys.executable, '-m', 'pip', 'install',
+                        '--target', str(Path(vd.options.visidata_dir)/"plugins-deps"),
+                      ] + deps,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE)
+    out, err = p.communicate()
+    vd.status(out.decode())
+    if err:
+        vd.warning(err.decode())
+        return False
+    return True
+
+
 class PluginsSheet(JsonLinesSheet):
     rowtype = "plugins"  # rowdef: AttrDict of json dict
     colorizers = [
@@ -67,7 +89,12 @@ class PluginsSheet(JsonLinesSheet):
 
     @asyncsingle
     def reload(self):
-        self.source = urlcache(options.plugins_url or vd.fail(), days=1)  # for VisiDataMetaSheet.reload()
+        try:
+            self.source = vd.urlcache(vd.options.plugins_url or vd.fail(), days=1)  # for VisiDataMetaSheet.reload()
+        except urllib.error.URLError as e:
+            vd.debug(e)
+            return
+
         super().reload.__wrapped__(self)
         self.addColumn(Column('available', width=0, getter=_installedStatus), index=1)
         self.addColumn(Column('installed', width=8, getter=lambda c,r: _loadedVersion(r)), index=2)
@@ -92,7 +119,7 @@ class PluginsSheet(JsonLinesSheet):
         overwrite = True
         if outpath.exists():
             try:
-                confirm("plugin path already exists, overwrite? ")
+                vd.confirm("plugin path already exists, overwrite? ")
             except ExpectedException:
                 overwrite = False
                 if _plugin_in_import_list(plugin):
@@ -115,24 +142,22 @@ class PluginsSheet(JsonLinesSheet):
             vd.status(out.decode())
             if err:
                 vd.warning(err.decode())
+            if p.returncode != 0:
+                vd.fail('pip install failed')
         else:
-            with urlcache(plugin.url, days=0).open_text(encoding='utf-8') as pyfp:
+            with vd.urlcache(plugin.url, days=0).open_text(encoding='utf-8') as pyfp:
                 contents = pyfp.read()
-                if not _checkHash(contents, plugin.sha256):
-                    vd.error('%s plugin SHA256 does not match!' % plugin.name)
+                if plugin.sha256:
+                    if not _checkHash(contents, plugin.sha256):
+                        vd.error('%s plugin SHA256 does not match!' % plugin.name)
+                else:
+                    vd.warning('no SHA256 provided for %s plugin, not validating' % plugin.name)
                 with outpath.open_text(mode='w', encoding='utf-8') as outfp:
                     outfp.write(contents)
 
         if plugin.pydeps:
-            p = subprocess.Popen([sys.executable, '-m', 'pip', 'install',
-                                '--target', str(Path(options.visidata_dir)/"plugins-deps"),
-                              ]+plugin.pydeps.split(),
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
-            out, err = p.communicate()
-            vd.status(out.decode())
-            if err:
-                vd.warning(err.decode())
+            vd.pipinstall(plugin.pydeps.split())
+
         vd.status('%s plugin installed' % plugin.name)
 
         if _plugin_in_import_list(plugin):
@@ -176,7 +201,8 @@ class PluginsSheet(JsonLinesSheet):
         except FileNotFoundError:
             vd.warning("no plugins/__init__.py found")
 
-globalCommand(None, 'open-plugins', 'vd.push(vd.pluginsSheet)', 'open Plugins Sheet: manage your session environment for a curated set of plugins')
 
-PluginsSheet.addCommand('a', 'add-plugin', 'installPlugin(cursorRow)', 'install and activate current plugin')
-PluginsSheet.addCommand('d', 'delete-plugin', 'removePluginIfExists(cursorRow)', 'deactivate current plugin')
+BaseSheet.addCommand(None, 'open-plugins', 'vd.push(vd.pluginsSheet)', 'Open Plugins Sheet to manage supported plugins')
+
+PluginsSheet.addCommand('a', 'add-plugin', 'installPlugin(cursorRow)', 'Install and enable current plugin')
+PluginsSheet.addCommand('d', 'delete-plugin', 'removePluginIfExists(cursorRow)', 'Disable current plugin')
