@@ -1,8 +1,8 @@
 import re
 import random
 
-from visidata import asyncthread, option, options, vd
-from visidata import BaseSheet, Sheet, Column, Progress
+from visidata import asyncthread, options, vd
+from visidata import VisiData, BaseSheet, Sheet, Column, Progress
 
 
 @Sheet.api
@@ -15,13 +15,15 @@ def setSubst(sheet, cols, rows):
     setValuesFromRegex(cols, rows, rex)
 
 
-option('regex_flags', 'I', 'flags to pass to re.compile() [AILMSUX]', replay=True)
-option('regex_maxsplit', 0, 'maxsplit to pass to regex.split', replay=True)
+vd.option('regex_flags', 'I', 'flags to pass to re.compile() [AILMSUX]', replay=True)
+vd.option('regex_maxsplit', 0, 'maxsplit to pass to regex.split', replay=True)
 
-def makeRegexSplitter(regex, origcol):
+@VisiData.api
+def makeRegexSplitter(vd, regex, origcol):
     return lambda row, regex=regex, origcol=origcol, maxsplit=options.regex_maxsplit: regex.split(origcol.getDisplayValue(row), maxsplit=maxsplit)
 
-def makeRegexMatcher(regex, origcol):
+@VisiData.api
+def makeRegexMatcher(vd, regex, origcol):
     def _regexMatcher(row):
         m = regex.search(origcol.getDisplayValue(row))
         if m:
@@ -66,7 +68,8 @@ def addRegexColumns(vs, regexMaker, origcol, regexstr):
     vs.addColumnAtCursor(*cols.values())
 
 
-def regexTransform(origcol, instr):
+@VisiData.api
+def regexTransform(vd, origcol, instr):
     i = indexWithEscape(instr, '/')
     if i is None:
         before = instr
@@ -76,6 +79,7 @@ def regexTransform(origcol, instr):
         after = instr[i+1:]
     return lambda col,row,origcol=origcol,before=before,after=after,flags=origcol.sheet.regex_flags(): re.sub(before, after, origcol.getDisplayValue(row), flags=flags)
 
+
 def indexWithEscape(s, char, escape_char='\\'):
     i=0
     while i < len(s):
@@ -90,7 +94,7 @@ def indexWithEscape(s, char, escape_char='\\'):
 
 @asyncthread
 def setValuesFromRegex(cols, rows, rex):
-    transforms = [regexTransform(col, rex) for col in cols]
+    transforms = [vd.regexTransform(col, rex) for col in cols]
     vd.addUndoSetValues(cols, rows)
     for r in Progress(rows, 'replacing'):
         for col, transform in zip(cols, transforms):
@@ -105,7 +109,7 @@ def regex_flags(sheet):
     return sum(getattr(re, f.upper()) for f in options.regex_flags)
 
 
-Sheet.addCommand(':', 'split-col', 'addRegexColumns(makeRegexSplitter, cursorCol, input("split regex: ", type="regex-split"))', 'add new columns from regex split; number of columns determined by example row at cursor')
+Sheet.addCommand(':', 'split-col', 'addRegexColumns(makeRegexSplitter, cursorCol, input("split regex: ", type="regex-split"))', 'Add new columns from regex split')
 Sheet.addCommand(';', 'capture-col', 'addRegexColumns(makeRegexMatcher, cursorCol, input("capture regex: ", type="regex-capture"))', 'add new column from capture groups of regex; requires example row')
 Sheet.addCommand('*', 'addcol-subst', 'addColumnAtCursor(Column(cursorCol.name + "_re", getter=regexTransform(cursorCol, input("transform column by regex: ", type="regex-subst"))))', 'add column derived from current column, replacing regex with subst (may include \1 backrefs)')
 Sheet.addCommand('g*', 'setcol-subst', 'setSubst([cursorCol], someSelectedRows)', 'regex/subst - modify selected rows in current column, replacing regex with subst, (may include backreferences \\1 etc)')
