@@ -1,10 +1,10 @@
 import collections
 import itertools
-from copy import copy
+from copy import copy, deepcopy
 import textwrap
 
 from visidata import VisiData, Extensible, globalCommand, ColumnAttr, ColumnItem, vd, ENTER, EscapeException, drawcache, drawcache_property, LazyChainMap, asyncthread, ExpectedException
-from visidata import (options, theme, Column, option, namedlist, SettableColumn,
+from visidata import (options, Column, namedlist, SettableColumn,
 TypedExceptionWrapper, BaseSheet, UNLOADED,
 vd, clipdraw, ColorAttr, update_attr, colors, undoAttrFunc)
 import visidata
@@ -16,63 +16,63 @@ vd.activePane = 1   # pane numbering starts at 1; pane 0 means active pane
 __all__ = ['RowColorizer', 'CellColorizer', 'ColumnColorizer', 'Sheet', 'TableSheet', 'IndexSheet', 'SheetsSheet', 'LazyComputeRow', 'SequenceSheet']
 
 
-option('default_width', 20, 'default column width', replay=True)   # TODO: make not replay and remove from markdown saver
-option('default_height', 10, 'default column height')
-option('textwrap_cells', True, 'wordwrap text for multiline rows')
+vd.option('default_width', 20, 'default column width', replay=True)   # TODO: make not replay and remove from markdown saver
+vd.option('default_height', 4, 'default column height')
+vd.option('textwrap_cells', True, 'wordwrap text for multiline rows')
 
-option('quitguard', False, 'confirm before quitting last sheet')
-option('debug', False, 'exit on error and display stacktrace')
-option('skip', 0, 'skip N rows before header', replay=True)
-option('header', 1, 'parse first N rows as column names', replay=True)
-option('load_lazy', False, 'load subsheets always (False) or lazily (True)')
+vd.option('quitguard', False, 'confirm before quitting modified sheet')
+vd.option('debug', False, 'exit on error and display stacktrace')
+vd.option('skip', 0, 'skip N rows before header', replay=True)
+vd.option('header', 1, 'parse first N rows as column names', replay=True)
+vd.option('load_lazy', False, 'load subsheets always (False) or lazily (True)')
 
-theme('force_256_colors', False, 'use 256 colors even if curses reports fewer')
+vd.option('force_256_colors', False, 'use 256 colors even if curses reports fewer')
 
-theme('disp_note_none', '⌀',  'visible contents of a cell whose value is None')
-theme('disp_truncator', '…', 'indicator that the contents are only partially visible')
-theme('disp_oddspace', '\u00b7', 'displayable character for odd whitespace')
-theme('disp_more_left', '<', 'header note indicating more columns to the left')
-theme('disp_more_right', '>', 'header note indicating more columns to the right')
-theme('disp_error_val', '', 'displayed contents for computation exception')
-theme('disp_ambig_width', 1, 'width to use for unicode chars marked ambiguous')
+vd.option('disp_note_none', '⌀',  'visible contents of a cell whose value is None')
+vd.option('disp_truncator', '…', 'indicator that the contents are only partially visible')
+vd.option('disp_oddspace', '\u00b7', 'displayable character for odd whitespace')
+vd.option('disp_more_left', '<', 'header note indicating more columns to the left')
+vd.option('disp_more_right', '>', 'header note indicating more columns to the right')
+vd.option('disp_error_val', '', 'displayed contents for computation exception')
+vd.option('disp_ambig_width', 1, 'width to use for unicode chars marked ambiguous')
 
-theme('disp_pending', '', 'string to display in pending cells')
-theme('note_pending', '⌛', 'note to display for pending cells')
-theme('note_format_exc', '?', 'cell note for an exception during formatting')
-theme('note_getter_exc', '!', 'cell note for an exception during computation')
-theme('note_type_exc', '!', 'cell note for an exception during type conversion')
+vd.option('disp_pending', '', 'string to display in pending cells')
+vd.option('note_pending', '⌛', 'note to display for pending cells')
+vd.option('note_format_exc', '?', 'cell note for an exception during formatting')
+vd.option('note_getter_exc', '!', 'cell note for an exception during computation')
+vd.option('note_type_exc', '!', 'cell note for an exception during type conversion')
 
-theme('color_note_pending', 'bold magenta', 'color of note in pending cells')
-theme('color_note_type', '226 yellow', 'color of cell note for non-str types in anytype columns')
-theme('color_note_row', '220 yellow', 'color of row note on left edge')
-theme('scroll_incr', 3, 'amount to scroll with scrollwheel')
-theme('disp_column_sep', '|', 'separator between columns')
-theme('disp_keycol_sep', '║', 'separator between key columns and rest of columns')
-theme('disp_rowtop_sep', '|', '') # ╷│┬╽⌜⌐▇
-theme('disp_rowmid_sep', '⁝', '') # ┃┊│█
-theme('disp_rowbot_sep', '⁝', '') # ┊┴╿⌞█⍿╵⎢┴⌊  ⋮⁝
-theme('disp_rowend_sep', '║', '') # ┊┴╿⌞█⍿╵⎢┴⌊
-theme('disp_keytop_sep', '║', '') # ╽╿┃╖╟
-theme('disp_keymid_sep', '║', '') # ╽╿┃
-theme('disp_keybot_sep', '║', '') # ╽╿┃╜‖
-theme('disp_endtop_sep', '║', '') # ╽╿┃╖╢
-theme('disp_endmid_sep', '║', '') # ╽╿┃
-theme('disp_endbot_sep', '║', '') # ╽╿┃╜‖
-theme('disp_selected_note', '•', '') #
-theme('disp_sort_asc', '↑↟⇞⇡⇧⇑', 'characters for ascending sort') # ↑▲↟↥↾↿⇞⇡⇧⇈⤉⤒⥔⥘⥜⥠⍏˄ˆ
-theme('disp_sort_desc', '↓↡⇟⇣⇩⇓', 'characters for descending sort') # ↓▼↡↧⇂⇃⇟⇣⇩⇊⤈⤓⥕⥙⥝⥡⍖˅ˇ
-theme('color_default', 'white on black', 'the default fg and bg colors')
-theme('color_default_hdr', 'bold', 'color of the column headers')
-theme('color_bottom_hdr', 'underline', 'color of the bottom header row')
-theme('color_current_row', 'reverse', 'color of the cursor row')
-theme('color_current_col', 'bold', 'color of the cursor column')
-theme('color_current_hdr', 'bold reverse', 'color of the header for the cursor column')
-theme('color_column_sep', '246 blue', 'color of column separators')
-theme('color_key_col', '81 cyan', 'color of key columns')
-theme('color_hidden_col', '8', 'color of hidden columns on metasheets')
-theme('color_selected_row', '215 yellow', 'color of selected rows')
-option('name_joiner', '_', 'string to join sheet or column names')
-option('value_joiner', ' ', 'string to join display values')
+vd.option('color_note_pending', 'bold magenta', 'color of note in pending cells')
+vd.option('color_note_type', '226 yellow', 'color of cell note for non-str types in anytype columns')
+vd.option('color_note_row', '220 yellow', 'color of row note on left edge')
+vd.option('scroll_incr', 3, 'amount to scroll with scrollwheel')
+vd.option('disp_column_sep', '|', 'separator between columns')
+vd.option('disp_keycol_sep', '║', 'separator between key columns and rest of columns')
+vd.option('disp_rowtop_sep', '|', '') # ╷│┬╽⌜⌐▇
+vd.option('disp_rowmid_sep', '⁝', '') # ┃┊│█
+vd.option('disp_rowbot_sep', '⁝', '') # ┊┴╿⌞█⍿╵⎢┴⌊  ⋮⁝
+vd.option('disp_rowend_sep', '║', '') # ┊┴╿⌞█⍿╵⎢┴⌊
+vd.option('disp_keytop_sep', '║', '') # ╽╿┃╖╟
+vd.option('disp_keymid_sep', '║', '') # ╽╿┃
+vd.option('disp_keybot_sep', '║', '') # ╽╿┃╜‖
+vd.option('disp_endtop_sep', '║', '') # ╽╿┃╖╢
+vd.option('disp_endmid_sep', '║', '') # ╽╿┃
+vd.option('disp_endbot_sep', '║', '') # ╽╿┃╜‖
+vd.option('disp_selected_note', '•', '') #
+vd.option('disp_sort_asc', '↑↟⇞⇡⇧⇑', 'characters for ascending sort') # ↑▲↟↥↾↿⇞⇡⇧⇈⤉⤒⥔⥘⥜⥠⍏˄ˆ
+vd.option('disp_sort_desc', '↓↡⇟⇣⇩⇓', 'characters for descending sort') # ↓▼↡↧⇂⇃⇟⇣⇩⇊⤈⤓⥕⥙⥝⥡⍖˅ˇ
+vd.option('color_default', 'white on black', 'the default fg and bg colors')
+vd.option('color_default_hdr', 'bold', 'color of the column headers')
+vd.option('color_bottom_hdr', 'underline', 'color of the bottom header row')
+vd.option('color_current_row', 'reverse', 'color of the cursor row')
+vd.option('color_current_col', 'bold', 'color of the cursor column')
+vd.option('color_current_hdr', 'bold reverse', 'color of the header for the cursor column')
+vd.option('color_column_sep', '246 blue', 'color of column separators')
+vd.option('color_key_col', '81 cyan', 'color of key columns')
+vd.option('color_hidden_col', '8', 'color of hidden columns on metasheets')
+vd.option('color_selected_row', '215 yellow', 'color of selected rows')
+vd.option('name_joiner', '_', 'string to join sheet or column names')
+vd.option('value_joiner', ' ', 'string to join display values')
 
 
 def splitcell(sheet, s, width=0):
@@ -175,7 +175,7 @@ class TableSheet(BaseSheet):
         ColumnColorizer(2, 'color_current_col', lambda s,c,r,v: c is s.cursorCol),
         ColumnColorizer(1, 'color_key_col', lambda s,c,r,v: c and c.keycol),
         CellColorizer(0, 'color_default', lambda s,c,r,v: True),
-        RowColorizer(2, 'color_selected_row', lambda s,c,r,v: s.isSelected(r)),
+        RowColorizer(2, 'color_selected_row', lambda s,c,r,v: r is not None and s.isSelected(r)),
         RowColorizer(1, 'color_error', lambda s,c,r,v: isinstance(r, (Exception, TypedExceptionWrapper))),
     ]
     nKeys = 0  # columns[:nKeys] are key columns
@@ -332,19 +332,16 @@ class TableSheet(BaseSheet):
 
     @property
     def bottomRowIndex(self):
-        return max(self._rowLayout.keys()) if self._rowLayout else self.topRowIndex+self.nScreenRows-1
+        return self.topRowIndex+self.nScreenRows-1
 
     @bottomRowIndex.setter
     def bottomRowIndex(self, newidx):
-        'Set topRowIndex, by getting height of *newidx* row and going backwards until more than nScreenRows is allocated.'
-        nrows = 0
-        i = 0
-        while nrows < self.nScreenRows and newidx-i >= 0:
-            h = self.calc_height(self.rows[newidx-i])
-            nrows += h
-            i += 1
+        self._topRowIndex = newidx-self.nScreenRows+1
 
-        self._topRowIndex = newidx-i+2 if nrows == self.nScreenRows-1 else newidx-self.nScreenRows+1
+    @drawcache_property
+    def rowHeight(self):
+        cols = self.visibleCols
+        return max(c.height for c in cols) if cols else 1
 
     def __deepcopy__(self, memo):
         'same as __copy__'
@@ -371,7 +368,7 @@ class TableSheet(BaseSheet):
     @property
     def nScreenRows(self):
         'Number of visible rows at the current window height.'
-        return self.windowHeight-self.nHeaderRows-self.nFooterRows
+        return (self.windowHeight-self.nHeaderRows-self.nFooterRows)//self.rowHeight
 
     @drawcache_property
     def nHeaderRows(self):
@@ -492,6 +489,8 @@ class TableSheet(BaseSheet):
             return
 
         for i, col in enumerate(cols):
+            col.name = self.maybeClean(col.name)
+
             vd.addUndo(self.columns.remove, col)
             if index is None:
                 index = len(self.columns)
@@ -523,8 +522,6 @@ class TableSheet(BaseSheet):
             if not col.keycol:
                 col.keycol = lastkeycol+1
                 lastkeycol += 1
-        # clears the keyCols cache
-        visidata.Extensible.clear_all_caches()
 
     def unsetKeys(self, cols):
         'Make all *cols* non-key columns.'
@@ -570,8 +567,6 @@ class TableSheet(BaseSheet):
             self.topRowIndex = self.cursorRowIndex
         elif self.bottomRowIndex < self.cursorRowIndex:
             self.bottomRowIndex = self.cursorRowIndex
-        elif self.bottomRowIndex == self.cursorRowIndex and self._rowLayout and self._rowLayout[self.bottomRowIndex][1] > 1:
-            self.bottomRowIndex = self.cursorRowIndex
 
         if self.cursorCol and self.cursorCol.keycol:
             return
@@ -651,12 +646,6 @@ class TableSheet(BaseSheet):
         hdrs = col.name.split('\n')
         for i in range(h):
             name = ' '  # save room at front for LeftMore or sorted arrow
-            for j, (sortcol, sortdir) in enumerate(self._ordering):
-                if col is sortcol:
-                    try:
-                        name = self.options.disp_sort_desc[j] if sortdir else self.options.disp_sort_asc[j]
-                    except IndexError:
-                        pass
 
             if h-i-1 < len(hdrs):
                 name += hdrs[::-1][h-i-1]
@@ -682,14 +671,22 @@ class TableSheet(BaseSheet):
         except ValueError:  # from .index
             pass
 
+        try:
+            A = ''
+            for j, (sortcol, sortdir) in enumerate(self._ordering):
+                if col is sortcol:
+                    A = self.options.disp_sort_desc[j] if sortdir else self.options.disp_sort_asc[j]
+                    scr.addstr(y+h-1, x, A, hdrcattr.attr)
+                    break
+        except IndexError:
+            pass
+
     def isVisibleIdxKey(self, vcolidx):
         'Return boolean: is given column index a key column?'
         return self.visibleCols[vcolidx] in self.keyCols
 
     def draw(self, scr):
         'Draw entire screen onto the `scr` curses object.'
-        vd.clearCaches()
-
         if not self.columns:
             if self.options.debug:
                 self.addColumn(Column())
@@ -728,7 +725,7 @@ class TableSheet(BaseSheet):
 
         y = headerRow + numHeaderRows
 
-        rows = self.rows[self.topRowIndex:min(self.topRowIndex+self.nScreenRows, self.nRows)]
+        rows = self.rows[self.topRowIndex:min(self.topRowIndex+self.nScreenRows+1, self.nRows)]
         self.checkCursorNoExceptions()
 
         for rowidx, row in enumerate(rows):
@@ -742,8 +739,6 @@ class TableSheet(BaseSheet):
         if vcolidx+1 < self.nVisibleCols:
             scr.addstr(headerRow, self.windowWidth-2, self.options.disp_more_right, colors.color_column_sep)
 
-        scr.refresh()
-
     def calc_height(self, row, displines=None, isNull=None):
             if displines is None:
                 displines = {}  # [vcolidx] -> list of lines in that cell
@@ -771,12 +766,7 @@ class TableSheet(BaseSheet):
                         lines = [cellval.display]
                     displines[vcolidx] = (col, cellval, lines)
 
-            heights = [0]
-            for col, cellval, lines in displines.values():
-                h = len(lines)   # of this cell
-                heights.append(min(col.height, h))
-
-            return max(heights)
+            return self.rowHeight
 
     def drawRow(self, scr, row, rowidx, ybase, rowcattr: ColorAttr, maxheight,
             isNull='',
@@ -800,7 +790,7 @@ class TableSheet(BaseSheet):
 
             # apply current row here instead of in a colorizer, because it needs to know dispRowIndex
             if rowidx == self.cursorRowIndex:
-                color_current_row = colors.get_color('color_current_row', 5)
+                color_current_row = colors.get_color('color_current_row', 2)
                 basecellcattr = sepcattr = update_attr(rowcattr, color_current_row)
             else:
                 basecellcattr = rowcattr
@@ -820,9 +810,10 @@ class TableSheet(BaseSheet):
                     cattr = update_attr(cattr, basecellcattr)
 
                     note = getattr(cellval, 'note', None)
+                    notewidth = 1 if note else 0
                     if note:
                         notecattr = update_attr(cattr, colors.get_color(cellval.notecolor), 10)
-                        clipdraw(scr, ybase, x+colwidth-len(note), note, notecattr.attr)
+                        clipdraw(scr, ybase, x+colwidth-notewidth, note, notecattr.attr)
 
                     if voffset >= 0:
                         if len(lines)-voffset > height:
@@ -873,7 +864,7 @@ class TableSheet(BaseSheet):
                                     sepchars = midsep
 
                         pre = disp_truncator if hoffset != 0 else disp_column_fill
-                        clipdraw(scr, y, x, (pre if colwidth > 2 else '')+line[hoffset:], cattr.attr, w=colwidth-(1 if note else 0))
+                        clipdraw(scr, y, x, (pre if colwidth > 2 else '')+line[hoffset:], cattr.attr, w=colwidth-notewidth)
                         vd.onMouse(scr, y, x, 1, colwidth, BUTTON3_RELEASED='edit-cell')
 
                         if x+colwidth+len(sepchars) <= self.windowWidth:
@@ -951,7 +942,7 @@ class IndexSheet(Sheet):
     precious = False
 
     columns = [
-        ColumnAttr('name'),
+        Column('name', getter=lambda c,r: r.names[-1], setter=lambda c,r,v: setitem(r.names, -1, v)),
         ColumnAttr('rows', 'nRows', type=int, width=9),
         ColumnAttr('cols', 'nCols', type=int),
         ColumnAttr('keys', 'keyColNames'),
@@ -972,9 +963,14 @@ class IndexSheet(Sheet):
 
     def addRow(self, sheet, **kwargs):
         super().addRow(sheet, **kwargs)
-        if not self.options.load_lazy:
+        if not self.options.load_lazy and not sheet.options.load_lazy:
             sheet.ensureLoaded()
 
+    @asyncthread
+    def reloadSheets(self, sheets):
+        for vs in vd.Progress(sheets):
+            vs.reload()
+
 
 class SheetsSheet(IndexSheet):
     columns = [
@@ -1005,14 +1001,14 @@ def _evalcontexts(vd):
 
 ## VisiData sheet manipulation
 
-@VisiData.global_api
+@VisiData.api
 def replace(vd, vs):
     'Replace top sheet with the given sheet `vs`.'
     vd.sheets.pop(0)
     return vd.push(vs)
 
 
-@VisiData.global_api
+@VisiData.api
 def remove(vd, vs):
     'Remove *vs* from sheets stack, without asking for confirmation.'
     if vs in vd.sheets:
@@ -1024,7 +1020,7 @@ def remove(vd, vs):
         vd.fail('sheet not on stack')
 
 
-@VisiData.global_api
+@VisiData.api
 def push(vd, vs, pane=0):
     'Push Sheet *vs* onto ``vd.sheets`` stack for *pane* (0 for active pane, -1 for inactive pane).  Remove from other position if already on sheets stack.'
     if not isinstance(vs, BaseSheet):
@@ -1037,8 +1033,8 @@ def push(vd, vs, pane=0):
     if pane == -1:
         vs.pane = 2 if vd.activePane == 1 else 1
     elif pane == 0:
-        if not vd.sheetstack(1): vs.pane=1
-        elif not vd.sheetstack(2) and vd.options.disp_splitwin_pct != 0: vs.pane=2
+        if not vd.sheetstack(1): vd.activePane=vs.pane=1
+        elif not vd.sheetstack(2) and vd.options.disp_splitwin_pct != 0: vd.activePane=vs.pane=2
         else: vs.pane = vd.activePane
     else:
         vs.pane = pane
@@ -1072,10 +1068,9 @@ def quit(vd, *sheets):
 
 @BaseSheet.api
 def confirmQuit(vs, verb='quit'):
-    if vs.options.quitguard:
-        if vs.precious and vs.hasBeenModified:
-            vd.draw_all()
-            vd.confirm(f'{verb} modified sheet "{vs.name}?" ')
+    if vs.options.quitguard and vs.precious and vs.hasBeenModified:
+        vd.draw_all()
+        vd.confirm(f'{verb} modified sheet "{vs.name}?" ')
     elif vs.options.getonly('quitguard', vs, False):  # if this sheet is specifically guarded
         vd.draw_all()
         vd.confirm(f'{verb} guarded sheet "{vs.name}?" ')
@@ -1095,13 +1090,14 @@ def newSheet(vd, name, ncols, **kwargs):
 
 
 @BaseSheet.api
-def releaseMemory(vs):
+def quitAndReleaseMemory(vs):
     'Release largest memory consumer refs on *vs* to free up memory.'
     if isinstance(vs.source, visidata.Path):
         vs.source.lines.clear() # clear cache of read lines
 
     if vs.precious: # only precious sheets have meaningful data
         vs.rows.clear()
+        vd.remove(vs)
         vd.allSheets.remove(vs)
 
 
@@ -1122,6 +1118,19 @@ def splitPane(sheet, pct=None):
 
     vd.options.disp_splitwin_pct = pct
 
+
+@Sheet.api
+def async_deepcopy(sheet, rowlist):
+    @asyncthread
+    def _async_deepcopy(newlist, oldlist):
+        for r in vd.Progress(oldlist, 'copying'):
+            newlist.append(deepcopy(r))
+
+    ret = []
+    _async_deepcopy(ret, rowlist)
+    return ret
+
+
 IndexSheet.class_options.header = 0
 IndexSheet.class_options.skip = 0
 
@@ -1130,7 +1139,7 @@ BaseSheet.init('pane', lambda: 1)
 globalCommand('S', 'sheets-stack', 'vd.push(vd.sheetsSheet)', 'open Sheets Stack: join or jump between the active sheets on the current stack')
 globalCommand('gS', 'sheets-all', 'vd.push(vd.allSheetsSheet)', 'open Sheets Sheet: join or jump between all sheets from current session')
 
-BaseSheet.addCommand('^R', 'reload-sheet', 'preloadHook(); reload(); recalc(); status("reloaded")', 'reload current sheet'),
+BaseSheet.addCommand('^R', 'reload-sheet', 'preloadHook(); reload(); recalc(); status("reloaded")', 'Reload current sheet'),
 Sheet.addCommand('^G', 'show-cursor', 'status(statusLine)', 'show cursor position and bounds of current sheet on status line'),
 
 Sheet.addCommand('!', 'key-col', 'toggleKeys([cursorCol])', 'toggle current column as a key column')
@@ -1141,8 +1150,8 @@ Sheet.addCommand('ge', 'setcol-input', 'cursorCol.setValuesTyped(selectedRows, i
 
 Sheet.addCommand('"', 'dup-selected', 'vs=copy(sheet); vs.name += "_selectedref"; vs.reload=lambda vs=vs,rows=selectedRows: setattr(vs, "rows", list(rows)); vd.push(vs)', 'open duplicate sheet with only selected rows'),
 Sheet.addCommand('g"', 'dup-rows', 'vs=copy(sheet); vs.name+="_copy"; vs.rows=list(rows); status("copied "+vs.name); vs.select(selectedRows); vd.push(vs)', 'open duplicate sheet with all rows'),
-Sheet.addCommand('z"', 'dup-selected-deep', 'vs = deepcopy(sheet); vs.name += "_selecteddeepcopy"; vs.rows = async_deepcopy(vs, selectedRows); vd.push(vs); status("pushed sheet with async deepcopy of selected rows")', 'open duplicate sheet with deepcopy of selected rows'),
-Sheet.addCommand('gz"', 'dup-rows-deep', 'vs = deepcopy(sheet); vs.name += "_deepcopy"; vs.rows = async_deepcopy(vs, rows); vd.push(vs); status("pushed sheet with async deepcopy of all rows")', 'open duplicate sheet with deepcopy of all rows'),
+Sheet.addCommand('z"', 'dup-selected-deep', 'vs = deepcopy(sheet); vs.name += "_selecteddeepcopy"; vs.rows = vs.async_deepcopy(selectedRows); vd.push(vs); status("pushed sheet with async deepcopy of selected rows")', 'open duplicate sheet with deepcopy of selected rows'),
+Sheet.addCommand('gz"', 'dup-rows-deep', 'vs = deepcopy(sheet); vs.name += "_deepcopy"; vs.rows = vs.async_deepcopy(rows); vd.push(vs); status("pushed sheet with async deepcopy of all rows")', 'open duplicate sheet with deepcopy of all rows'),
 
 Sheet.addCommand('z~', 'type-any', 'cursorCol.type = anytype', 'set type of current column to anytype')
 Sheet.addCommand('~', 'type-string', 'cursorCol.type = str', 'set type of current column to str')
@@ -1155,7 +1164,7 @@ Sheet.addCommand('z%', 'type-floatsi', 'cursorCol.type = floatsi', 'set type of
 Sheet.addCommand('', 'type-floatlocale', 'cursorCol.type = floatlocale', 'set type of current column to float using system locale set in LC_NUMERIC')
 
 # when diving into a sheet, remove the index unless it is precious
-IndexSheet.addCommand('g^R', 'reload-selected', 'for vs in selectedRows or rows: vs.reload()', 'reload all selected sheets')
+IndexSheet.addCommand('g^R', 'reload-selected', 'reloadSheets(selectedRows or rows)', 'reload all selected sheets')
 SheetsSheet.addCommand('gC', 'columns-selected', 'vd.push(ColumnsSheet("all_columns", source=selectedRows))', 'open Columns Sheet with all visible columns from selected sheets')
 SheetsSheet.addCommand('gI', 'describe-selected', 'vd.push(DescribeSheet("describe_all", source=selectedRows))', 'open Describe Sheet with all visble columns from selected sheets')
 SheetsSheet.addCommand('z^C', 'cancel-row', 'cancelThread(*cursorRow.currentThreads)', 'abort async thread for current sheet')
@@ -1163,7 +1172,7 @@ SheetsSheet.addCommand('gz^C', 'cancel-rows', 'for vs in selectedRows: cancelThr
 SheetsSheet.addCommand(ENTER, 'open-row', 'dest=cursorRow; vd.sheets.remove(sheet) if not sheet.precious else None; vd.push(openRow(dest))', 'open sheet referenced in current row')
 
 BaseSheet.addCommand('q', 'quit-sheet',  'vd.quit(sheet)', 'quit current sheet')
-BaseSheet.addCommand('Q', 'quit-sheet-free',  'releaseMemory(); vd.quit(sheet)', 'discard current sheet and free memory')
+BaseSheet.addCommand('Q', 'quit-sheet-free',  'quitAndReleaseMemory()', 'discard current sheet and free memory')
 globalCommand('gq', 'quit-all', 'vd.quit(*vd.sheets)', 'quit all sheets (clean exit)')
 
 BaseSheet.addCommand('Z', 'splitwin-half', 'splitPane(vd.options.disp_splitwin_pct or 50)', 'ensure split pane is set and push under sheet onto other pane')
@@ -1172,16 +1181,16 @@ BaseSheet.addCommand('^I', 'splitwin-swap', 'vd.activePane = 1 if sheet.pane ==
 BaseSheet.addCommand('g^I', 'splitwin-swap-pane', 'vd.options.disp_splitwin_pct=-vd.options.disp_splitwin_pct', 'swap panes onscreen')
 BaseSheet.addCommand('zZ', 'splitwin-input', 'vd.options.disp_splitwin_pct = input("% height for split window: ", value=vd.options.disp_splitwin_pct)', 'set split pane to specific size')
 
-BaseSheet.addCommand('^L', 'redraw', 'vd.redraw(); sheet.refresh()', 'refresh screen')
-BaseSheet.addCommand(None, 'guard-sheet', 'options.set("quitguard", True, sheet); status("guarded")', 'guard current sheet from accidental quitting')
+BaseSheet.addCommand('^L', 'redraw', 'vd.redraw(); sheet.refresh()', 'Refresh screen')
+BaseSheet.addCommand(None, 'guard-sheet', 'options.set("quitguard", True, sheet); status("guarded")', 'Set quitguard on current sheet to confirm before quit')
 BaseSheet.addCommand(None, 'open-source', 'vd.push(source)', 'jump to the source of this sheet')
 
 BaseSheet.bindkey('KEY_RESIZE', 'redraw')
 
-BaseSheet.addCommand('A', 'open-new', 'vd.push(vd.newSheet("unnamed", 1))', 'open new blank sheet')
+BaseSheet.addCommand('A', 'open-new', 'vd.push(vd.newSheet("unnamed", 1))', 'Open new empty sheet')
 
 Sheet.addCommand('^', 'rename-col', 'vd.addUndoColNames([cursorCol]); cursorCol.name = editCell(cursorVisibleColIndex, -1)', 'edit name of current column')
 Sheet.addCommand('z^', 'rename-col-selected', 'updateColNames(selectedRows or [cursorRow], [sheet.cursorCol], overwrite=True)', 'set name of current column to combined contents of current cell in selected rows (or current row)')
 Sheet.addCommand('g^', 'rename-cols-row', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols)', 'set names of all unnamed visible columns to contents of selected rows (or current row)')
 Sheet.addCommand('gz^', 'rename-cols-selected', 'updateColNames(selectedRows or [cursorRow], sheet.visibleCols, overwrite=True)', 'set names of all visible columns to combined contents of selected rows (or current row)')
-BaseSheet.addCommand(None, 'rename-sheet', 'sheet.name = input("rename sheet to: ", value=sheet.name)', 'rename current sheet to input')
+BaseSheet.addCommand(None, 'rename-sheet', 'sheet.name = input("rename sheet to: ", value=sheet.name)', 'Rename current sheet')
