@@ -1,9 +1,6 @@
 import os
-import io
 import shutil
-import sys
 import stat
-import locale
 import subprocess
 import contextlib
 try:
@@ -12,13 +9,13 @@ try:
 except ImportError:
     pass # pwd,grp modules not available on Windows
 
-from visidata import Column, Sheet, LazyComputeRow, asynccache, options, option, globalCommand, vd
-from visidata import Path, ENTER, date, asyncthread, confirm, fail, FileExistsError, VisiData
-from visidata import CellColorizer, RowColorizer, modtime, filesize, vstat, Progress
+from visidata import Column, Sheet, LazyComputeRow, asynccache, BaseSheet, vd
+from visidata import Path, ENTER, date, asyncthread, FileExistsError, VisiData
+from visidata import modtime, filesize, vstat, Progress, TextSheet
 
 
-option('dir_recurse', False, 'walk source path recursively on DirSheet')
-option('dir_hidden', False, 'load hidden files on DirSheet')
+vd.option('dir_recurse', False, 'walk source path recursively on DirSheet')
+vd.option('dir_hidden', False, 'load hidden files on DirSheet')
 
 
 @VisiData.lazy_property
@@ -35,13 +32,16 @@ def exec_shell(*args):
         vd.push(TextSheet(' '.join(args), source=lines))
 
 
-def open_dir(p):
+@VisiData.api
+def open_dir(vd, p):
     return DirSheet(p.name, source=p)
 
-def open_fdir(p):
+@VisiData.api
+def open_fdir(vd, p):
     return FileListSheet(p.name, source=p)
 
-def addShellColumns(cmd, sheet):
+@VisiData.api
+def addShellColumns(vd, cmd, sheet):
     shellcol = ColumnShell(cmd, source=sheet, width=0)
     sheet.addColumnAtCursor(
             shellcol,
@@ -215,7 +215,7 @@ def inputShell(vd):
         vd.warning('no $column in command')
     return cmd
 
-globalCommand('', 'open-dir-current', 'vd.push(vd.currentDirSheet)', 'open Directory Sheet: browse properties of files in current directory')
+BaseSheet.addCommand('', 'open-dir-current', 'vd.push(vd.currentDirSheet)', 'open Directory Sheet: browse properties of files in current directory')
 
 Sheet.addCommand('z;', 'addcol-sh', 'cmd=inputShell(); addShellColumns(cmd, sheet)', 'create new column from bash expression, with $columnNames as variables')
 
@@ -230,8 +230,21 @@ DirSheet.addCommand('gy', 'copy-selected', 'copy_files(selectedRows, inputPath("
 @DirSheet.api
 @asyncthread
 def copy_files(sheet, paths, dest):
-    dest = Path(dest)
-    dest.is_dir() or vd.fail('target must be directory')
-    vd.status('copying %s %s to %s' % (len(paths), sheet.rowtype, dest))
-    for p in Progress(paths, gerund='copying'):
-        shutil.copyfile(p, dest/(p.parts[-1]))
+    destdir = Path(dest)
+    destdir.is_dir() or vd.fail('target must be directory')
+    vd.status('copying %s %s to %s' % (len(paths), sheet.rowtype, destdir))
+    os.makedirs(destdir, exist_ok=True)
+    for srcpath in Progress(paths, gerund='copying'):
+        try:
+            destpath = destdir/str(srcpath._path.name)
+            if srcpath.is_dir():
+                shutil.copy_tree(srcpath, destpath)
+            else:
+                shutil.copyfile(srcpath, destpath)
+        except Exception as e:
+            vd.exceptionCaught(e)
+
+
+vd.addGlobals({
+    'DirSheet': DirSheet
+})
