@@ -1,11 +1,11 @@
 import itertools
 from copy import copy
 
-from visidata import vd, options, VisiData, BaseSheet, option, UNLOADED
+from visidata import vd, options, VisiData, BaseSheet, UNLOADED
 
 BaseSheet.init('undone', list)  # list of CommandLogRow for redo after undo
 
-option('undo', True, 'enable undo/redo')
+vd.option('undo', True, 'enable undo/redo')
 
 nonUndo = '''commit open-file'''.split()
 
@@ -37,7 +37,7 @@ def undo(vd, sheet):
     # don't allow undo of first command on a sheet, which is always the command that created the sheet.
     for cmdlogrow in sheet.cmdlog_sheet.rows[:0:-1]:
         if cmdlogrow.undofuncs:
-            for undofunc, args, kwargs, in cmdlogrow.undofuncs:
+            for undofunc, args, kwargs, in cmdlogrow.undofuncs[::-1]:
                 undofunc(*args, **kwargs)
             sheet.undone.append(cmdlogrow)
             sheet.cmdlog_sheet.rows.remove(cmdlogrow)
@@ -109,5 +109,5 @@ def addUndoColNames(vd, cols):
     vd.addUndo(_undo)
 
 
-BaseSheet.addCommand('U', 'undo-last', 'vd.undo(sheet)', 'undo the most recent modification (requires enabled options.undo)')
-BaseSheet.addCommand('R', 'redo-last', 'vd.redo(sheet)', 'redo the most recent undo (requires enabled options.undo)')
+BaseSheet.addCommand('U', 'undo-last', 'vd.undo(sheet)', 'Undo the most recent change (options.undo must be enabled)')
+BaseSheet.addCommand('R', 'redo-last', 'vd.redo(sheet)', 'Redo the most recent undo (options.undo must be enabled)')
